@@ -12,7 +12,7 @@ class OpeningHoursWidget(Widget):
     template = "opening_hours/widget.html"
     def render(self, name, value, attrs=None):
         if not value:
-            value = '{"first_day": "mo", "mo": [], "tu":[], "we":[], "th":[], "fr":[], "sa":[], "su":[], "mo_note": "", "tu_note": "", "we_note":"", "th_note":"", "fr_note":"", "sa_note":"", "su_note":"" }'
+            value = {"first_day": "mo", "mo": [], "tu":[], "we":[], "th":[], "fr":[], "sa":[], "su":[], "mo_note": "", "tu_note": "", "we_note":"", "th_note":"", "fr_note":"", "sa_note":"", "su_note":""}
         return mark_safe(loader.render_to_string(self.template, {
             "value": json.dumps(value),
             "name": name,
